# frozen_string_literal: true

require 'tmpdir'
require 'securerandom'

namespace :styleguide do
  desc 'Update the RoQua styleguide to the latest version'
  task :update do # rubocop:disable Rails/RakeEnvironment
    puts 'Updating styleguide'
    system('bundle update roqua_styleguide')

    # Run in a separate process so the files from the updated gem version are copied
    system('bundle exec rake styleguide:inject_styles')
  end

  task :inject_styles do # rubocop:disable Rails/RakeEnvironment
    FileUtils.rm_rf('./styleguide')
    FileUtils.mkdir_p('./styleguide/ruby')

    full_gem_path = Gem.loaded_specs['roqua_styleguide'].full_gem_path
    output_path = File.join('./styleguide', 'ruby')

    FileUtils.cp File.join(full_gem_path, 'ruby', 'rubocop.yml'), output_path

    if defined?(Rails)
      FileUtils.cp File.join(full_gem_path, 'ruby', "rubocop-rails.yml"), output_path
    end
  end
end
